Credits
=======

``dj-pro`` was created by `Franco Gidaszewski <https://github.com/szew404>`_.

Acknowledgments
===============

The existence of ``dj-pro`` would have been impossible without these
projects:

- `django <https://github.com/django/django>`_
- `joke2k/django-environ <https://github.com/joke2k/django-environ>`_
- `encode/django-rest-framework <https://github.com/encode/django-rest-framework>`_
- `unfoldadmin/django-unfold <https://github.com/unfoldadmin/django-unfold>`_